==> Botania-1.19.2-438-FABRIC-20230214.034242-11-sources.jar: vazkii/botania/test/item/FlowerPouchTest.java <==
package vazkii.botania.test.item;

import net.minecraft.class_1277;
import net.minecraft.class_1542;
import net.minecraft.class_1657;
import net.minecraft.class_1767;
import net.minecraft.class_1799;
import net.minecraft.class_4516;
import net.minecraft.class_6302;
import vazkii.botania.common.block.BotaniaBlocks;
import vazkii.botania.common.item.BotaniaItems;
import vazkii.botania.common.item.FlowerPouchItem;
import vazkii.botania.test.TestingUtil;

public class FlowerPouchTest {
	@class_6302(method_35936 = TestingUtil.EMPTY_STRUCTURE)
	public void testNoShinyFlowers(class_4516 helper) {
		var player = helper.method_36021();
		var bag = new class_1799(BotaniaItems.flowerBag);
		player.method_31548().method_5447(1, bag);

		var flower = new class_1542(player.field_6002, player.method_23317(), player.method_23318(), player.method_23321(), new class_1799(BotaniaBlocks.blackShinyFlower, 64));
		TestingUtil.assertThat(!FlowerPouchItem.onPickupItem(flower, player), () -> "Should not pick up glimmering flowers");

		TestingUtil.assertEquals(flower.method_6983().method_7909(), BotaniaBlocks.blackShinyFlower.method_8389());
		TestingUtil.assertEquals(flower.method_6983().method_7947(), 64);

		var inv = FlowerPouchItem.getInventory(bag);
		for (int i = 0; i < inv.method_5439(); i++) {
			TestingUtil.assertThat(inv.method_5438(i).method_7960(), () -> "Bag should be empty");
		}
		helper.method_36036();
	}

	@class_6302(method_35936 = TestingUtil.EMPTY_STRUCTURE)
	public void testPickupBasic(class_4516 helper) {
		var player = helper.method_36021();
		var bag = new class_1799(BotaniaItems.flowerBag);
		player.method_31548().method_5447(1, bag);

		var flower = new class_1542(player.field_6002, player.method_23317(), player.method_23318(), player.method_23321(), new class_1799(BotaniaBlocks.blackFlower, 64));
		TestingUtil.assertThat(FlowerPouchItem.onPickupItem(flower, player), () -> "Pickup should succeed since the bag has room");
		TestingUtil.assertThat(flower.method_6983().method_7960(), () -> "Should have consumed everything");

		var flowerInBag = FlowerPouchItem.getInventory(bag).method_5438(class_1767.field_7963.method_7789());
		TestingUtil.assertThat(!flowerInBag.method_7960(), () -> "Bag should have an item in black slot");
		TestingUtil.assertEquals(flowerInBag.method_7909(), BotaniaBlocks.blackFlower.method_8389());
		TestingUtil.assertEquals(flowerInBag.method_7947(), 64);
		helper.method_36036();
	}
}

==> Botania-1.20.1-451-FABRIC-20250904.193711-3-sources.jar: vazkii/botania/test/item/FlowerPouchTest.java <==
package vazkii.botania.test.item;

import net.minecraft.class_1277;
import net.minecraft.class_1542;
import net.minecraft.class_1657;
import net.minecraft.class_1767;
import net.minecraft.class_1799;
import net.minecraft.class_4516;
import net.minecraft.class_6302;
import vazkii.botania.common.block.BotaniaBlocks;
import vazkii.botania.common.item.BotaniaItems;
import vazkii.botania.common.item.FlowerPouchItem;
import vazkii.botania.test.TestingUtil;

public class FlowerPouchTest {
	@class_6302(method_35936 = TestingUtil.EMPTY_STRUCTURE)
	public void testNoShinyFlowers(class_4516 helper) {
		var player = helper.method_36021();
		var bag = new class_1799(BotaniaItems.flowerBag);
		player.method_31548().method_5447(1, bag);

		var flower = new class_1542(player.method_37908(), player.method_23317(), player.method_23318(), player.method_23321(), new class_1799(BotaniaBlocks.blackShinyFlower, 64));
		TestingUtil.assertThat(!FlowerPouchItem.onPickupItem(flower, player), () -> "Should not pick up glimmering flowers");

		TestingUtil.assertEquals(flower.method_6983().method_7909(), BotaniaBlocks.blackShinyFlower.method_8389());
		TestingUtil.assertEquals(flower.method_6983().method_7947(), 64);

		var inv = FlowerPouchItem.getInventory(bag);
		for (int i = 0; i < inv.method_5439(); i++) {
			TestingUtil.assertThat(inv.method_5438(i).method_7960(), () -> "Bag should be empty");
		}
		helper.method_36036();
	}

	@class_6302(method_35936 = TestingUtil.EMPTY_STRUCTURE)
	public void testPickupBasic(class_4516 helper) {
		var player = helper.method_36021();
		var bag = new class_1799(BotaniaItems.flowerBag);
		player.method_31548().method_5447(1, bag);

		var flower = new class_1542(player.method_37908(), player.method_23317(), player.method_23318(), player.method_23321(), new class_1799(BotaniaBlocks.blackFlower, 64));
		TestingUtil.assertThat(FlowerPouchItem.onPickupItem(flower, player), () -> "Pickup should succeed since the bag has room");
		TestingUtil.assertThat(flower.method_6983().method_7960(), () -> "Should have consumed everything");

		var flowerInBag = FlowerPouchItem.getInventory(bag).method_5438(class_1767.field_7963.method_7789());
		TestingUtil.assertThat(!flowerInBag.method_7960(), () -> "Bag should have an item in black slot");
		TestingUtil.assertEquals(flowerInBag.method_7909(), BotaniaBlocks.blackFlower.method_8389());
		TestingUtil.assertEquals(flowerInBag.method_7947(), 64);
		helper.method_36036();
	}
}
